// REFERENCE 1
// Simple Proximity Sensor using Infrared
// Description: Measure the distance to an obstacle using infrared light emitted by IR LED and 
//   read the value with a IR photodiode. The accuracy is not perfect, but works great 
//   with minor projects.
// Author: Ricardo Ouvina
// Date: 01/10/2012
// Version: 1.0

// REFERENCE 2
/*
  Example for MCP3008 - Library for communicating with MCP3008 Analog to digital converter.
  Created by Uros Petrevski, Nodesign.net 2013
  Released into the public domain.
*/

#include <MCP3008.h>
#include <Wire.h>
#include <L3G.h>
#include <LSM303.h>

// define pin connections
#define CS_PIN 9
#define CLOCK_PIN 8
#define MOSI_PIN 6
#define MISO_PIN 7
#define BASE_PIN 4
#define NO_OF_PHTRANS 8
#define FSRPIN A4

int ambientIR[8];                // variable to store the IR coming from the ambient
int obstacleIR[8];               // variable to store the IR coming from the object
int value[8][10];                // variable to store the IR values
int distance[8];                 // variable that represents the distance of the object to the sensor (unit is a scaled voltage difference)

int times = 4;                   // amount of samples to the averaging filter

// Serial communication variables
int serialvalue;                 // serial input value

// Gyro & compass
L3G gyro;
LSM303 compass;

// FSR
int fsrval = 0;

// MCP3008 constructor
MCP3008 adc(CLOCK_PIN, MOSI_PIN, MISO_PIN, CS_PIN);

void setup() {
 
// open serial port (baud rate)
 Serial.begin(115200);
 
// Setup IMU with error handling
 Wire.begin();
 if (!gyro.init())
  {
    Serial.println("Failed to autodetect gyro type!");
    while (1);
  }
  if (!compass.init())
  {
    Serial.println("Failed to initialize compass!");
    while (1);
  }
gyro.enableDefault();
compass.enableDefault(); 
 
 // Configure Base Pin (IR LEDs) and turn off
 pinMode(BASE_PIN,OUTPUT);      // Transistor Base to turn on all the IR emitter LED on digital pin 4
 digitalWrite(BASE_PIN,LOW);    // Turn IR LEDs off
 
 establishContact();            // send a byte to establish contact until receiver responds 
}


void loop() {
  
  if(Serial.available() > 0)       // check to see if there's serial data in the buffer
    {
      serialvalue = Serial.read(); // read a byte of serial data

    /*============================================
       IR HANDCUPPING 
    ============================================*/

    // READ SENSOR VALUES FOR HAND CUPPING GESTURE
     for(int x=0;x<times;x++){
       
        // OFF
        digitalWrite(BASE_PIN,LOW);                    //turning the IR LEDs off to read the IR coming from the ambient
        delay(1);                                      // minimum delay necessary to read values
        
        // READ
        for (int i=0; i<NO_OF_PHTRANS; i++) {
          ambientIR[i] = adc.readADC(i);               // storing IR coming from the ambient
        }
        
        // ON
        digitalWrite(BASE_PIN,HIGH);                   //turning the IR LEDs on to read the IR coming from the obstacle
        delay(1);                                      // minimum delay necessary to read values
        
        // READ
        for (int i=0; i<NO_OF_PHTRANS; i++) {
          obstacleIR[i] = adc.readADC(i);              // storing IR coming from the obstacle
          
          // TAKE DIFFERENCE
          value[i][x] = ambientIR[i]-obstacleIR[i];    // calculating changes in IR values and storing it for future average
        }
    }
    
    for(int x=0;x<times;x++){          // calculating the average based on the "accuracy"
      for (int i=0; i<NO_OF_PHTRANS; i++) {
        distance[i]+=value[i][x];
      }
    }
    for (int i=0; i<NO_OF_PHTRANS; i++) {
      distance[i] = distance[i]/times;       // final mean value
      Serial.print(distance[i]);
      Serial.print(" ");
    }
    
    /*============================================
       FORCE SENSING RESISTOR
    ============================================*/
    
    fsrval = analogRead(FSRPIN);
    Serial.print(fsrval);
    Serial.print(" ");

    /*============================================
       INERTIAL MEASUREMENT UNIT
    ============================================*/
    
    readGyro();
    Serial.println();
    
  }
}

void establishContact() {
  while (Serial.available() <= 0) {
    Serial.println("whatevs");   // send an initial string
    delay(300);
  }
}


void readGyro() {
  gyro.read();
  compass.read();
  
  // X
  Serial.print(((int)gyro.g.x));
  Serial.print(" ");
  // Y
  Serial.print(((int)gyro.g.y));
  Serial.print(" ");
  // Z
  Serial.print(((int)gyro.g.z));
  Serial.print(" ");
  // Yaw
  Serial.print(((int)compass.a.x));
  Serial.print(" ");
  // Pitch
  Serial.print(((int)compass.a.y));
  Serial.print(" ");
  // Roll
  Serial.print(((int)compass.a.z));
  Serial.print(" ");

}
